---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

Describe the bug here, the expected behaviour and what you actually observed as detailed as possible


**To Reproduce**
1. Describe the steps to reproduce the bug
2. ...

```python
# Include a minimal but complete code example to reproduce the bug
```


**Stack Trace**
```
If applicable, paste the full stack trace here
```


**Screenshots**
Add screenshots to help explain the issue


**Environment**
- OS
- Python and library versions (output of `pip freeze | grep ^x`)
- Git revision
